#!/bin/bash
#
# scmi.sh:	this runs the SCMI service
#
# chkconfig: 35 96 99
# description:  this runs the SCMI Java service
#               SCMI = Source Code Management Interface
#		An SCMI service provides a gateway to an SCM system
#		for a Krugle Enterprise Appliance
#               $Id:$

# Krugle Enterprise SCMI
# you must edit USER and SCMIDIR
#
# the user which your SCMI will run as
# USER=<username>

# the location of the SCMI components you've installed.  
# usually under $USER's home dir
SCMIDIR=/home/$USER/clearcase-scmi-4.0.2

# we must use a different service name for each possible 
# SCMIDIR and instance we run simultaneously on the same box
MYNAME=clearcase-scmi

# ----- typically no user editing required below this line -----

# Source function library.
. /etc/rc.d/init.d/functions

start() {
    APP=$SCMIDIR/bin/run.sh

    if [ -d $SCMIDIR ] && [ -x $APP ] ; then
        echo $"Starting Krugle Enterprise ${MYNAME} SCMI "`basename $SCMIDIR`
        echo ""

        # note that daemon factors some of the common init script
        #    "am I already running?" logic
        # but does not
        #     make the job run in the background
        #     actually write the /var/run/$ME.pid file

        # KKr - I create an empty file with the owner set to $USER so that
        # the run.sh script can write the PID there when being run as $USER
        if [ ! -f /var/run/$MYNAME.pid ] ; then
                echo "" > /var/run/$MYNAME.pid
                chown $USER /var/run/$MYNAME.pid
        fi

        cd $SCMIDIR
        daemon --user $USER --check $MYNAME "$APP /var/run/$MYNAME.pid"
    else
        echo "Could Not Find Krugle Enterprise ${MYNAME} SCMI ${SCMIDIR}"
        exit 3
    fi 	
}

stop() {
    # killproc factors the common init script "kill this job" logic
    #   by looking at /var/run/$MYNAME.pid and so forth
    killproc $MYNAME
}

# See how we were called.
case "$1" in
    start)
        start
        ;;
	
    stop)
        stop
        ;;
	
    status)
        ;;
        
    restart)
        stop
        start
        ;;
        
    condrestart)
        ;;
        
    reload)
        ;;
        
    *)
        echo $"Usage: $0 {start|stop|status|restart|condrestart|reload}"
        ;;
esac
exit $RETVAL
